@@ -9,6 +9,9 @@ def run_script(argv):
     try:
         spec = importlib.util.spec_from_file_location("torun", argv[0])
         module = importlib.util.module_from_spec(spec)
+    except AttributeError:
+        exit("script mode - error - the first argument shall be a python file")
+    try:
         spec.loader.exec_module(module)
     except Exception:
         traceback.print_exc()
