@@ -3,11 +3,12 @@ var k7_id = null;
 
 function refresh_resquests() {
     var table = document.getElementById("requests-list");
-    var template = document.getElementById("template_request").innerHTML;
-    fetch("http://localhost:5000/requests")
+    var template_request = document.getElementById("template_request").innerHTML;
+    var template_source = document.getElementById("template_source").innerHTML;
+    fetch("/requests")
         .then(res => res.json())
         .then(data => {
-            if(data["id"] != k7_id){
+            if (data["id"] != k7_id) {
                 table.getElementsByTagName("tbody")[0].innerHTML = '';
                 document.getElementById("headers").innerHTML = 'select a request to view details';
                 document.getElementById("cookies").innerHTML = 'select a request to view details';
@@ -15,38 +16,57 @@ function refresh_resquests() {
                 document.getElementById("body_received").innerHTML = 'select a request to view details';
             };
             k7_id = data["id"];
-            
-            data["requests"].forEach(request => {    
-            if (! document.getElementById("request-" + request.id)){
-                var rendered = Mustache.render(template, request);
-                table.getElementsByTagName("tbody")[0].insertAdjacentHTML("beforeend", rendered);
-            };
-        })})
+
+            var tbody = table.getElementsByTagName("tbody")[0];
+
+            data["requests"].forEach(request => {
+                if (!document.getElementById("request-" + request.id)) {
+
+                    if (request.src) {
+                        if (!document.getElementById("source-" + request.src.id)) {
+                            var rendered = Mustache.render(template_source, request.src);
+                            tbody.insertAdjacentHTML("beforeend", rendered);
+                        }
+                    }
+
+                    var rendered = Mustache.render(template_request, request);
+                    if (request.src) {
+                        var last_row = document.querySelector("[data-source='" + request.src.id + "']:last-of-type");
+                        last_row.insertAdjacentHTML("afterend", rendered);
+                    } else {
+                        tbody.insertAdjacentHTML("beforeend", rendered);
+                    }
+                };
+            })
+        })
         .then(enable_refresh())
         .catch((error) => {
             console.error('Error:', error);
             disable_refresh();
-            });
+        });
 };
 
-
-function disable_refresh(){
+function disable_refresh() {
     document.getElementById("refresh").style.display = "block";
-    if(refresh != null)
+    if (refresh != null)
         clearInterval(refresh);
-    refresh = setInterval(function () {  refresh_resquests(); }, 20000);
+    refresh = setInterval(function () {
+        refresh_resquests();
+    }, 20000);
 }
 
 
-function enable_refresh(){
+function enable_refresh() {
     document.getElementById("refresh").style.display = "none";
-    if(refresh != null)
+    if (refresh != null)
         clearInterval(refresh);
-    refresh = setInterval(function () {  refresh_resquests(); }, 2000);
+    refresh = setInterval(function () {
+        refresh_resquests();
+    }, 2000);
 }
 
 
-function update_with_template(template_id, target_id, data){
+function update_with_template(template_id, target_id, data) {
     var template = document.getElementById(template_id).innerHTML;
     var rendered = Mustache.render(template, data);
     document.getElementById(target_id).innerHTML = rendered;
@@ -56,30 +76,30 @@ function update_with_template(template_id, target_id, data){
 function show_request(request_id) {
 
     var active_rows = document.getElementsByClassName("active-row");
-    [].forEach.call(active_rows, function(el) {
+    [].forEach.call(active_rows, function (el) {
         el.classList.remove("active-row");
     });
 
     document.getElementById("request-" + request_id).classList.add("active-row");
 
-    fetch("http://localhost:5000/request/" + request_id)
+    fetch("/request/" + request_id)
         .then(res => res.json())
         .then(data => function (data) {
 
-            update_with_template("template_headers", "headers", data);
+                update_with_template("template_headers", "headers", data);
 
-            update_with_template("template_cookies", "cookies", data);
+                update_with_template("template_cookies", "cookies", data);
 
-            update_with_template("template_body", "body_sent", data.request);
+                update_with_template("template_body", "body_sent", data.request);
 
-            update_with_template("template_body", "body_received", data.response);
-        }
-    (data));
+                update_with_template("template_body", "body_received", data.response);
+            }
+            (data));
 }
 
 
 function opentab(btn, tabname) {
-   
+
     var i, tabcontent, tablinks;
 
     tabcontent = document.getElementsByClassName("tabcontent");
